@@ -22,16 +22,13 @@ else:
 
 if features['qtwebkit']:
     from PyQt5.QtWebKitWidgets import QWebView
-    print("Debug: Web rendering engine used: QWebView")
     webEngine = "QtWebKit"
     webView = QWebView
 elif features['qtwebengine']:
     from PyQt5 import QtWebEngineWidgets
-    print("Debug: Web rendering engine used: QWebEngineView")
     webEngine = "QtWebEngine"
     webView = QtWebEngineWidgets.QWebEngineView
 else:
     from PyQt5.QtWidgets import QTextEdit
-    print("Debug: Web rendering engine used: QTextEdit")
     webEngine = "QTextEdit"
     webView = QTextEdit
